Crate graphify_hooks

Crate graphify_hooks 

Git hook integration for graphify.

Installs/uninstalls post-commit and post-checkout hooks that trigger incremental graph rebuilds. Port of Python hooks.py.

Enums

HookError
Errors from hook management.

Functions

hook_status
Check whether graphify hooks are installed in the repository at repo_root.
install_hooks
Install graphify git hooks in the repository at repo_root.
uninstall_hooks
Uninstall graphify git hooks from the repository at repo_root.