install_hooks

Function install_hooks 

pub fn install_hooks(repo_root: &Path) -> Result<String, HookError>
Install graphify git hooks in the repository at repo_root.

Installs post-commit and post-checkout hooks. If the hook files already exist, the graphify block is appended (or replaced if already present).