uninstall_hooks

Function uninstall_hooks 

pub fn uninstall_hooks(repo_root: &Path) -> Result<String, HookError>
Uninstall graphify git hooks from the repository at repo_root.

Removes the graphify marker block from each managed hook file. If the resulting file contains only the shebang line (or is empty), the hook file is deleted.